# Generated by ariadne-codegen
# Source: combined.graphql

from uuid import UUID

from .base_model import BaseModel


class Deploy(BaseModel):
    deploy: "DeployDeploy"


class DeployDeploy(BaseModel):
    id: UUID
    path: str


Deploy.model_rebuild()
DeployDeploy.model_rebuild()



# Generated by ariadne-codegen
# Source: combined.graphql

from datetime import datetime
from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class ProteinConformer(BaseModel):
    protein_conformer: Optional["ProteinConformerProteinConformer"]


class ProteinConformerProteinConformer(BaseModel):
    id: Any
    created_at: datetime = Field(alias="createdAt")
    updated_at: datetime = Field(alias="updatedAt")
    deleted_at: Optional[datetime] = Field(alias="deletedAt")
    data: Optional["ProteinConformerProteinConformerData"]
    tags: List[str]


class ProteinConformerProteinConformerData(BaseModel):
    name: Optional[str]


ProteinConformer.model_rebuild()
ProteinConformerProteinConformer.model_rebuild()
ProteinConformerProteinConformerData.model_rebuild()



# Generated by ariadne-codegen
# Source: combined.graphql

from datetime import datetime
from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class Experiment(BaseModel):
    experiment: Optional["ExperimentExperiment"]


class ExperimentExperiment(BaseModel):
    id: Any
    created_at: datetime = Field(alias="createdAt")
    updated_at: datetime = Field(alias="updatedAt")
    deleted_at: Optional[datetime] = Field(alias="deletedAt")
    data: Optional["ExperimentExperimentData"]
    tags: List[str]


class ExperimentExperimentData(BaseModel):
    name: str
    unit: str
    measure: str
    value: float
    assay: str


Experiment.model_rebuild()
ExperimentExperiment.model_rebuild()
ExperimentExperimentData.model_rebuild()



# Generated by ariadne-codegen
# Source: combined.graphql

from datetime import datetime
from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class Protein(BaseModel):
    protein: Optional["ProteinProtein"]


class ProteinProtein(BaseModel):
    id: Any
    created_at: datetime = Field(alias="createdAt")
    updated_at: datetime = Field(alias="updatedAt")
    deleted_at: Optional[datetime] = Field(alias="deletedAt")
    data: Optional["ProteinProteinData"]
    tags: List[str]


class ProteinProteinData(BaseModel):
    name: str
    sequence: str


Protein.model_rebuild()
ProteinProtein.model_rebuild()
ProteinProteinData.model_rebuild()



# Generated by ariadne-codegen
# Source: combined.graphql

from datetime import datetime
from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class Smol(BaseModel):
    smol: Optional["SmolSmol"]


class SmolSmol(BaseModel):
    id: Any
    created_at: datetime = Field(alias="createdAt")
    updated_at: datetime = Field(alias="updatedAt")
    deleted_at: Optional[datetime] = Field(alias="deletedAt")
    data: Optional["SmolSmolData"]
    tags: List[str]


class SmolSmolData(BaseModel):
    name: str
    inchi: str


Smol.model_rebuild()
SmolSmol.model_rebuild()
SmolSmolData.model_rebuild()



# Generated by ariadne-codegen
# Source: combined.graphql

from typing import Any

from .base_model import BaseModel


class CreateSmolTautomer(BaseModel):
    create_smol_tautomer: "CreateSmolTautomerCreateSmolTautomer"


class CreateSmolTautomerCreateSmolTautomer(BaseModel):
    id: Any


CreateSmolTautomer.model_rebuild()
CreateSmolTautomerCreateSmolTautomer.model_rebuild()



# Generated by ariadne-codegen
# Source: combined.graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel
from .fragments import PageInfoFull, SimpleModuleInstanceFull


class ModuleInstances(BaseModel):
    me: "ModuleInstancesMe"


class ModuleInstancesMe(BaseModel):
    account: Optional["ModuleInstancesMeAccount"]


class ModuleInstancesMeAccount(BaseModel):
    module_instances: "ModuleInstancesMeAccountModuleInstances"


class ModuleInstancesMeAccountModuleInstances(BaseModel):
    edges: List["ModuleInstancesMeAccountModuleInstancesEdges"]
    page_info: "ModuleInstancesMeAccountModuleInstancesPageInfo" = Field(
        alias="pageInfo"
    )


class ModuleInstancesMeAccountModuleInstancesEdges(BaseModel):
    cursor: str
    node: "ModuleInstancesMeAccountModuleInstancesEdgesNode"


class ModuleInstancesMeAccountModuleInstancesEdgesNode(SimpleModuleInstanceFull):
    pass


class ModuleInstancesMeAccountModuleInstancesPageInfo(PageInfoFull):
    pass


ModuleInstances.model_rebuild()
ModuleInstancesMe.model_rebuild()
ModuleInstancesMeAccount.model_rebuild()
ModuleInstancesMeAccountModuleInstances.model_rebuild()
ModuleInstancesMeAccountModuleInstancesEdges.model_rebuild()
ModuleInstancesMeAccountModuleInstancesEdgesNode.model_rebuild()
ModuleInstancesMeAccountModuleInstancesPageInfo.model_rebuild()



# Generated by ariadne-codegen
# Source: combined.graphql

from datetime import datetime
from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class Project(BaseModel):
    project: Optional["ProjectProject"]


class ProjectProject(BaseModel):
    created_at: datetime = Field(alias="createdAt")
    updated_at: datetime = Field(alias="updatedAt")
    deleted_at: Optional[datetime] = Field(alias="deletedAt")
    data: Optional["ProjectProjectData"]
    tags: List[str]
    proteins: "ProjectProjectProteins"
    protein_conformers: "ProjectProjectProteinConformers"
    smols: "ProjectProjectSmols"
    smol_conformers: "ProjectProjectSmolConformers"
    smol_tautomers: "ProjectProjectSmolTautomers"


class ProjectProjectData(BaseModel):
    name: str


class ProjectProjectProteins(BaseModel):
    edges: List["ProjectProjectProteinsEdges"]


class ProjectProjectProteinsEdges(BaseModel):
    node: "ProjectProjectProteinsEdgesNode"


class ProjectProjectProteinsEdgesNode(BaseModel):
    id: Any


class ProjectProjectProteinConformers(BaseModel):
    edges: List["ProjectProjectProteinConformersEdges"]


class ProjectProjectProteinConformersEdges(BaseModel):
    node: "ProjectProjectProteinConformersEdgesNode"


class ProjectProjectProteinConformersEdgesNode(BaseModel):
    id: Any


class ProjectProjectSmols(BaseModel):
    edges: List["ProjectProjectSmolsEdges"]


class ProjectProjectSmolsEdges(BaseModel):
    node: "ProjectProjectSmolsEdgesNode"


class ProjectProjectSmolsEdgesNode(BaseModel):
    id: Any


class ProjectProjectSmolConformers(BaseModel):
    edges: List["ProjectProjectSmolConformersEdges"]


class ProjectProjectSmolConformersEdges(BaseModel):
    node: "ProjectProjectSmolConformersEdgesNode"


class ProjectProjectSmolConformersEdgesNode(BaseModel):
    id: Any


class ProjectProjectSmolTautomers(BaseModel):
    edges: List["ProjectProjectSmolTautomersEdges"]


class ProjectProjectSmolTautomersEdges(BaseModel):
    node: "ProjectProjectSmolTautomersEdgesNode"


class ProjectProjectSmolTautomersEdgesNode(BaseModel):
    id: Any


Project.model_rebuild()
ProjectProject.model_rebuild()
ProjectProjectData.model_rebuild()
ProjectProjectProteins.model_rebuild()
ProjectProjectProteinsEdges.model_rebuild()
ProjectProjectProteinsEdgesNode.model_rebuild()
ProjectProjectProteinConformers.model_rebuild()
ProjectProjectProteinConformersEdges.model_rebuild()
ProjectProjectProteinConformersEdgesNode.model_rebuild()
ProjectProjectSmols.model_rebuild()
ProjectProjectSmolsEdges.model_rebuild()
ProjectProjectSmolsEdgesNode.model_rebuild()
ProjectProjectSmolConformers.model_rebuild()
ProjectProjectSmolConformersEdges.model_rebuild()
ProjectProjectSmolConformersEdgesNode.model_rebuild()
ProjectProjectSmolTautomers.model_rebuild()
ProjectProjectSmolTautomersEdges.model_rebuild()
ProjectProjectSmolTautomersEdgesNode.model_rebuild()



# Generated by ariadne-codegen
# Source: combined.graphql

from typing import Any

from .base_model import BaseModel


class CreateProtein(BaseModel):
    create_protein: "CreateProteinCreateProtein"


class CreateProteinCreateProtein(BaseModel):
    id: Any


CreateProtein.model_rebuild()
CreateProteinCreateProtein.model_rebuild()



# Generated by ariadne-codegen
# Source: combined.graphql

from uuid import UUID

from .base_model import BaseModel


class Retry(BaseModel):
    retry: "RetryRetry"


class RetryRetry(BaseModel):
    id: UUID


Retry.model_rebuild()
RetryRetry.model_rebuild()



# Generated by ariadne-codegen
# Source: combined.graphql

from typing import Any

from .base_model import BaseModel


class CreateProject(BaseModel):
    create_project: "CreateProjectCreateProject"


class CreateProjectCreateProject(BaseModel):
    id: Any


CreateProject.model_rebuild()
CreateProjectCreateProject.model_rebuild()



# Generated by ariadne-codegen
# Source: combined.graphql

from typing import Any

from .base_model import BaseModel


class CreateSmolConformer(BaseModel):
    create_smol_conformer: "CreateSmolConformerCreateSmolConformer"


class CreateSmolConformerCreateSmolConformer(BaseModel):
    id: Any


CreateSmolConformer.model_rebuild()
CreateSmolConformerCreateSmolConformer.model_rebuild()



# Generated by ariadne-codegen

from .argument import Argument, ArgumentArgument
from .arguments import (
    Arguments,
    ArgumentsMe,
    ArgumentsMeAccount,
    ArgumentsMeAccountArguments,
    ArgumentsMeAccountArgumentsEdges,
    ArgumentsMeAccountArgumentsEdgesNode,
    ArgumentsMeAccountArgumentsPageInfo,
)
from .async_base_client import AsyncBaseClient
from .base_model import BaseModel, Upload
from .cancel_module_instance import CancelModuleInstance
from .client import Client
from .create_entity import CreateEntity, CreateEntityCreateEntity
from .create_experiment import CreateExperiment, CreateExperimentCreateExperiment
from .create_project import CreateProject, CreateProjectCreateProject
from .create_protein import CreateProtein, CreateProteinCreateProtein
from .create_protein_conformer import (
    CreateProteinConformer,
    CreateProteinConformerCreateProteinConformer,
)
from .create_smol import CreateSmol, CreateSmolCreateSmol
from .create_smol_conformer import (
    CreateSmolConformer,
    CreateSmolConformerCreateSmolConformer,
)
from .create_smol_tautomer import (
    CreateSmolTautomer,
    CreateSmolTautomerCreateSmolTautomer,
)
from .create_structure import CreateStructure, CreateStructureCreateStructure
from .delete_module_instance import (
    DeleteModuleInstance,
    DeleteModuleInstanceDeleteModuleInstance,
)
from .deploy import Deploy, DeployDeploy
from .entity import Entity, EntityEntity
from .enums import (
    Element,
    MemUnits,
    ModuleFailureReason,
    ModuleInstanceStatus,
    ModuleInstanceTarget,
    Order,
    OrderBy,
)
from .exceptions import (
    GraphQLClientError,
    GraphQLClientGraphQLError,
    GraphQLClientGraphQLMultiError,
    GraphQLClientHttpError,
    GraphQlClientInvalidResponseError,
)
from .experiment import Experiment, ExperimentExperiment, ExperimentExperimentData
from .fragments import (
    ArgumentFull,
    ModuleFull,
    ModuleFullResourceBounds,
    ModuleInstanceCommon,
    ModuleInstanceCommonFailureContext,
    ModuleInstanceFull,
    ModuleInstanceFullIns,
    ModuleInstanceFullOuts,
    ModuleInstanceFullProgress,
    ModuleInstanceFullResources,
    PageInfoFull,
    SimpleModuleInstanceCommon,
    SimpleModuleInstanceCommonFailureContext,
    SimpleModuleInstanceFull,
    SimpleModuleInstanceFullIns,
    SimpleModuleInstanceFullOuts,
    SimpleModuleInstanceFullProgress,
    SimpleModuleInstanceFullResources,
)
from .input_types import (
    ArgumentInput,
    CreateExperimentInput,
    CreateProjectInput,
    CreateProteinConformerInput,
    CreateProteinInput,
    CreateSmolConformerInput,
    CreateSmolInput,
    CreateSmolTautomerInput,
    CreateStructureInput,
    DateTimeFilter,
    EntityFilterBy,
    EntitySortBy,
    ExperimentDataInput,
    ExperimentFilterBy,
    ExperimentSortBy,
    ModuleInput,
    ModuleInstanceInput,
    ModuleInstanceResourcesInput,
    ProjectFilterBy,
    ProjectSortBy,
    ProteinConformerFilterBy,
    ProteinConformerSortBy,
    ProteinFilterBy,
    ProteinSortBy,
    RawEntityInput,
    ResourceUtilizationInput,
    SmolConformerFilterBy,
    SmolConformerSortBy,
    SmolDataInput,
    SmolFilterBy,
    SmolSortBy,
    SmolTautomerDataInput,
    SmolTautomerFilterBy,
    SmolTautomerSortBy,
    StringFilter,
    StructureFilterBy,
    StructureSortBy,
    TagFilter,
    TestCase,
    TokenFilterBy,
    TokenSortBy,
    TopologyInput,
    UpdateModuleInstanceInput,
    UuidFilter,
)
from .latest_modules import (
    LatestModules,
    LatestModulesLatestModules,
    LatestModulesLatestModulesEdges,
    LatestModulesLatestModulesEdgesNode,
    LatestModulesLatestModulesPageInfo,
)
from .module_instance_details import (
    ModuleInstanceDetails,
    ModuleInstanceDetailsModuleInstance,
    ModuleInstanceDetailsModuleInstanceStderr,
    ModuleInstanceDetailsModuleInstanceStderrEdges,
    ModuleInstanceDetailsModuleInstanceStderrEdgesNode,
    ModuleInstanceDetailsModuleInstanceStderrPageInfo,
    ModuleInstanceDetailsModuleInstanceStdout,
    ModuleInstanceDetailsModuleInstanceStdoutEdges,
    ModuleInstanceDetailsModuleInstanceStdoutEdgesNode,
    ModuleInstanceDetailsModuleInstanceStdoutPageInfo,
)
from .module_instance_minimal import (
    ModuleInstanceMinimal,
    ModuleInstanceMinimalModuleInstance,
)
from .module_instances import (
    ModuleInstances,
    ModuleInstancesMe,
    ModuleInstancesMeAccount,
    ModuleInstancesMeAccountModuleInstances,
    ModuleInstancesMeAccountModuleInstancesEdges,
    ModuleInstancesMeAccountModuleInstancesEdgesNode,
    ModuleInstancesMeAccountModuleInstancesPageInfo,
)
from .modules import (
    Modules,
    ModulesModules,
    ModulesModulesEdges,
    ModulesModulesEdgesNode,
    ModulesModulesPageInfo,
)
from .object import Object
from .project import (
    Project,
    ProjectProject,
    ProjectProjectData,
    ProjectProjectProteinConformers,
    ProjectProjectProteinConformersEdges,
    ProjectProjectProteinConformersEdgesNode,
    ProjectProjectProteins,
    ProjectProjectProteinsEdges,
    ProjectProjectProteinsEdgesNode,
    ProjectProjectSmolConformers,
    ProjectProjectSmolConformersEdges,
    ProjectProjectSmolConformersEdgesNode,
    ProjectProjectSmols,
    ProjectProjectSmolsEdges,
    ProjectProjectSmolsEdgesNode,
    ProjectProjectSmolTautomers,
    ProjectProjectSmolTautomersEdges,
    ProjectProjectSmolTautomersEdgesNode,
)
from .protein import Protein, ProteinProtein, ProteinProteinData
from .protein_conformer import (
    ProteinConformer,
    ProteinConformerProteinConformer,
    ProteinConformerProteinConformerData,
)
from .retry import Retry, RetryRetry
from .run import Run, RunRun, RunRunOuts
from .smol import Smol, SmolSmol, SmolSmolData
from .smol_conformer import (
    SmolConformer,
    SmolConformerSmolConformer,
    SmolConformerSmolConformerData,
)
from .smol_tautomer import (
    SmolTautomer,
    SmolTautomerSmolTautomer,
    SmolTautomerSmolTautomerData,
)
from .structure import (
    Structure,
    StructureStructure,
    StructureStructureData,
    StructureStructureTopology,
)
from .tag import Tag
from .track_utilization import (
    TrackUtilization,
    TrackUtilizationTrackModuleInstanceResourceUtilization,
)
from .untag import Untag
from .update_module_instance import (
    UpdateModuleInstance,
    UpdateModuleInstanceUpdateModuleInstance,
)
from .upload_arg import UploadArg, UploadArgUploadArg

__all__ = [
    "Argument",
    "ArgumentArgument",
    "ArgumentFull",
    "ArgumentInput",
    "Arguments",
    "ArgumentsMe",
    "ArgumentsMeAccount",
    "ArgumentsMeAccountArguments",
    "ArgumentsMeAccountArgumentsEdges",
    "ArgumentsMeAccountArgumentsEdgesNode",
    "ArgumentsMeAccountArgumentsPageInfo",
    "AsyncBaseClient",
    "BaseModel",
    "CancelModuleInstance",
    "Client",
    "CreateEntity",
    "CreateEntityCreateEntity",
    "CreateExperiment",
    "CreateExperimentCreateExperiment",
    "CreateExperimentInput",
    "CreateProject",
    "CreateProjectCreateProject",
    "CreateProjectInput",
    "CreateProtein",
    "CreateProteinConformer",
    "CreateProteinConformerCreateProteinConformer",
    "CreateProteinConformerInput",
    "CreateProteinCreateProtein",
    "CreateProteinInput",
    "CreateSmol",
    "CreateSmolConformer",
    "CreateSmolConformerCreateSmolConformer",
    "CreateSmolConformerInput",
    "CreateSmolCreateSmol",
    "CreateSmolInput",
    "CreateSmolTautomer",
    "CreateSmolTautomerCreateSmolTautomer",
    "CreateSmolTautomerInput",
    "CreateStructure",
    "CreateStructureCreateStructure",
    "CreateStructureInput",
    "DateTimeFilter",
    "DeleteModuleInstance",
    "DeleteModuleInstanceDeleteModuleInstance",
    "Deploy",
    "DeployDeploy",
    "Element",
    "Entity",
    "EntityEntity",
    "EntityFilterBy",
    "EntitySortBy",
    "Experiment",
    "ExperimentDataInput",
    "ExperimentExperiment",
    "ExperimentExperimentData",
    "ExperimentFilterBy",
    "ExperimentSortBy",
    "GraphQLClientError",
    "GraphQLClientGraphQLError",
    "GraphQLClientGraphQLMultiError",
    "GraphQLClientHttpError",
    "GraphQlClientInvalidResponseError",
    "LatestModules",
    "LatestModulesLatestModules",
    "LatestModulesLatestModulesEdges",
    "LatestModulesLatestModulesEdgesNode",
    "LatestModulesLatestModulesPageInfo",
    "MemUnits",
    "ModuleFailureReason",
    "ModuleFull",
    "ModuleFullResourceBounds",
    "ModuleInput",
    "ModuleInstanceCommon",
    "ModuleInstanceCommonFailureContext",
    "ModuleInstanceDetails",
    "ModuleInstanceDetailsModuleInstance",
    "ModuleInstanceDetailsModuleInstanceStderr",
    "ModuleInstanceDetailsModuleInstanceStderrEdges",
    "ModuleInstanceDetailsModuleInstanceStderrEdgesNode",
    "ModuleInstanceDetailsModuleInstanceStderrPageInfo",
    "ModuleInstanceDetailsModuleInstanceStdout",
    "ModuleInstanceDetailsModuleInstanceStdoutEdges",
    "ModuleInstanceDetailsModuleInstanceStdoutEdgesNode",
    "ModuleInstanceDetailsModuleInstanceStdoutPageInfo",
    "ModuleInstanceFull",
    "ModuleInstanceFullIns",
    "ModuleInstanceFullOuts",
    "ModuleInstanceFullProgress",
    "ModuleInstanceFullResources",
    "ModuleInstanceInput",
    "ModuleInstanceMinimal",
    "ModuleInstanceMinimalModuleInstance",
    "ModuleInstanceResourcesInput",
    "ModuleInstanceStatus",
    "ModuleInstanceTarget",
    "ModuleInstances",
    "ModuleInstancesMe",
    "ModuleInstancesMeAccount",
    "ModuleInstancesMeAccountModuleInstances",
    "ModuleInstancesMeAccountModuleInstancesEdges",
    "ModuleInstancesMeAccountModuleInstancesEdgesNode",
    "ModuleInstancesMeAccountModuleInstancesPageInfo",
    "Modules",
    "ModulesModules",
    "ModulesModulesEdges",
    "ModulesModulesEdgesNode",
    "ModulesModulesPageInfo",
    "Object",
    "Order",
    "OrderBy",
    "PageInfoFull",
    "Project",
    "ProjectFilterBy",
    "ProjectProject",
    "ProjectProjectData",
    "ProjectProjectProteinConformers",
    "ProjectProjectProteinConformersEdges",
    "ProjectProjectProteinConformersEdgesNode",
    "ProjectProjectProteins",
    "ProjectProjectProteinsEdges",
    "ProjectProjectProteinsEdgesNode",
    "ProjectProjectSmolConformers",
    "ProjectProjectSmolConformersEdges",
    "ProjectProjectSmolConformersEdgesNode",
    "ProjectProjectSmolTautomers",
    "ProjectProjectSmolTautomersEdges",
    "ProjectProjectSmolTautomersEdgesNode",
    "ProjectProjectSmols",
    "ProjectProjectSmolsEdges",
    "ProjectProjectSmolsEdgesNode",
    "ProjectSortBy",
    "Protein",
    "ProteinConformer",
    "ProteinConformerFilterBy",
    "ProteinConformerProteinConformer",
    "ProteinConformerProteinConformerData",
    "ProteinConformerSortBy",
    "ProteinFilterBy",
    "ProteinProtein",
    "ProteinProteinData",
    "ProteinSortBy",
    "RawEntityInput",
    "ResourceUtilizationInput",
    "Retry",
    "RetryRetry",
    "Run",
    "RunRun",
    "RunRunOuts",
    "SimpleModuleInstanceCommon",
    "SimpleModuleInstanceCommonFailureContext",
    "SimpleModuleInstanceFull",
    "SimpleModuleInstanceFullIns",
    "SimpleModuleInstanceFullOuts",
    "SimpleModuleInstanceFullProgress",
    "SimpleModuleInstanceFullResources",
    "Smol",
    "SmolConformer",
    "SmolConformerFilterBy",
    "SmolConformerSmolConformer",
    "SmolConformerSmolConformerData",
    "SmolConformerSortBy",
    "SmolDataInput",
    "SmolFilterBy",
    "SmolSmol",
    "SmolSmolData",
    "SmolSortBy",
    "SmolTautomer",
    "SmolTautomerDataInput",
    "SmolTautomerFilterBy",
    "SmolTautomerSmolTautomer",
    "SmolTautomerSmolTautomerData",
    "SmolTautomerSortBy",
    "StringFilter",
    "Structure",
    "StructureFilterBy",
    "StructureSortBy",
    "StructureStructure",
    "StructureStructureData",
    "StructureStructureTopology",
    "Tag",
    "TagFilter",
    "TestCase",
    "TokenFilterBy",
    "TokenSortBy",
    "TopologyInput",
    "TrackUtilization",
    "TrackUtilizationTrackModuleInstanceResourceUtilization",
    "Untag",
    "UpdateModuleInstance",
    "UpdateModuleInstanceInput",
    "UpdateModuleInstanceUpdateModuleInstance",
    "Upload",
    "UploadArg",
    "UploadArgUploadArg",
    "UuidFilter",
]



# Generated by ariadne-codegen
# Source: combined.graphql

from typing import Any, Dict, List, Optional, Union
from uuid import UUID

from .argument import Argument, ArgumentArgument
from .arguments import Arguments, ArgumentsMe
from .async_base_client import AsyncBaseClient
from .base_model import UNSET, UnsetType, Upload
from .cancel_module_instance import CancelModuleInstance
from .create_entity import CreateEntity, CreateEntityCreateEntity
from .create_experiment import CreateExperiment, CreateExperimentCreateExperiment
from .create_project import CreateProject, CreateProjectCreateProject
from .create_protein import CreateProtein, CreateProteinCreateProtein
from .create_protein_conformer import (
    CreateProteinConformer,
    CreateProteinConformerCreateProteinConformer,
)
from .create_smol import CreateSmol, CreateSmolCreateSmol
from .create_smol_conformer import (
    CreateSmolConformer,
    CreateSmolConformerCreateSmolConformer,
)
from .create_smol_tautomer import (
    CreateSmolTautomer,
    CreateSmolTautomerCreateSmolTautomer,
)
from .create_structure import CreateStructure, CreateStructureCreateStructure
from .delete_module_instance import (
    DeleteModuleInstance,
    DeleteModuleInstanceDeleteModuleInstance,
)
from .deploy import Deploy, DeployDeploy
from .entity import Entity, EntityEntity
from .enums import ModuleInstanceStatus, ModuleInstanceTarget, OrderBy
from .experiment import Experiment, ExperimentExperiment
from .input_types import (
    CreateExperimentInput,
    CreateProjectInput,
    CreateProteinConformerInput,
    CreateProteinInput,
    CreateSmolConformerInput,
    CreateSmolInput,
    CreateSmolTautomerInput,
    CreateStructureInput,
    ModuleInput,
    ModuleInstanceInput,
    ModuleInstanceResourcesInput,
    RawEntityInput,
    ResourceUtilizationInput,
    UpdateModuleInstanceInput,
)
from .latest_modules import LatestModules, LatestModulesLatestModules
from .module_instance_details import (
    ModuleInstanceDetails,
    ModuleInstanceDetailsModuleInstance,
)
from .module_instance_minimal import (
    ModuleInstanceMinimal,
    ModuleInstanceMinimalModuleInstance,
)
from .module_instances import ModuleInstances, ModuleInstancesMe
from .modules import Modules, ModulesModules
from .object import Object
from .project import Project, ProjectProject
from .protein import Protein, ProteinProtein
from .protein_conformer import ProteinConformer, ProteinConformerProteinConformer
from .retry import Retry, RetryRetry
from .run import Run, RunRun
from .smol import Smol, SmolSmol
from .smol_conformer import SmolConformer, SmolConformerSmolConformer
from .smol_tautomer import SmolTautomer, SmolTautomerSmolTautomer
from .structure import Structure, StructureStructure
from .tag import Tag
from .track_utilization import (
    TrackUtilization,
    TrackUtilizationTrackModuleInstanceResourceUtilization,
)
from .untag import Untag
from .update_module_instance import (
    UpdateModuleInstance,
    UpdateModuleInstanceUpdateModuleInstance,
)
from .upload_arg import UploadArg, UploadArgUploadArg


def gql(q: str) -> str:
    return q


class Client(AsyncBaseClient):
    async def cancel_module_instance(
        self, module_instance_id: UUID, **kwargs: Any
    ) -> UUID:
        query = gql(
            """
            mutation cancel_module_instance($moduleInstanceId: ModuleInstanceId!) {
              cancel(instance: $moduleInstanceId)
            }
            """
        )
        variables: Dict[str, object] = {"moduleInstanceId": module_instance_id}
        response = await self.execute(query=query, variables=variables, **kwargs)
        data = self.get_data(response)
        return CancelModuleInstance.model_validate(data).cancel

    async def delete_module_instance(
        self, module_instance_id: UUID, **kwargs: Any
    ) -> DeleteModuleInstanceDeleteModuleInstance:
        query = gql(
            """
            mutation delete_module_instance($moduleInstanceId: ModuleInstanceId!) {
              delete_module_instance(module: $moduleInstanceId) {
                id
              }
            }
            """
        )
        variables: Dict[str, object] = {"moduleInstanceId": module_instance_id}
        response = await self.execute(query=query, variables=variables, **kwargs)
        data = self.get_data(response)
        return DeleteModuleInstance.model_validate(data).delete_module_instance

    async def deploy(self, module: ModuleInput, **kwargs: Any) -> DeployDeploy:
        query = gql(
            """
            mutation deploy($module: ModuleInput!) {
              deploy(module: $module) {
                id
                path
              }
            }
            """
        )
        variables: Dict[str, object] = {"module": module}
        response = await self.execute(query=query, variables=variables, **kwargs)
        data = self.get_data(response)
        return Deploy.model_validate(data).deploy

    async def create_entity(
        self, entity: RawEntityInput, **kwargs: Any
    ) -> CreateEntityCreateEntity:
        query = gql(
            """
            mutation create_entity($entity: RawEntityInput!) {
              create_entity(entity: $entity) {
                id
              }
            }
            """
        )
        variables: Dict[str, object] = {"entity": entity}
        response = await self.execute(query=query, variables=variables, **kwargs)
        data = self.get_data(response)
        return CreateEntity.model_validate(data).create_entity

    async def create_experiment(
        self, experiment: CreateExperimentInput, **kwargs: Any
    ) -> CreateExperimentCreateExperiment:
        query = gql(
            """
            mutation create_experiment($experiment: CreateExperimentInput!) {
              create_experiment(input: $experiment) {
                id
              }
            }
            """
        )
        variables: Dict[str, object] = {"experiment": experiment}
        response = await self.execute(query=query, variables=variables, **kwargs)
        data = self.get_data(response)
        return CreateExperiment.model_validate(data).create_experiment

    async def create_project(
        self, project: CreateProjectInput, **kwargs: Any
    ) -> CreateProjectCreateProject:
        query = gql(
            """
            mutation create_project($project: CreateProjectInput!) {
              create_project(input: $project) {
                id
              }
            }
            """
        )
        variables: Dict[str, object] = {"project": project}
        response = await self.execute(query=query, variables=variables, **kwargs)
        data = self.get_data(response)
        return CreateProject.model_validate(data).create_project

    async def create_protein_conformer(
        self, protein_conformer: CreateProteinConformerInput, **kwargs: Any
    ) -> CreateProteinConformerCreateProteinConformer:
        query = gql(
            """
            mutation create_protein_conformer($protein_conformer: CreateProteinConformerInput!) {
              create_protein_conformer(input: $protein_conformer) {
                id
              }
            }
            """
        )
        variables: Dict[str, object] = {"protein_conformer": protein_conformer}
        response = await self.execute(query=query, variables=variables, **kwargs)
        data = self.get_data(response)
        return CreateProteinConformer.model_validate(data).create_protein_conformer

    async def create_protein(
        self, protein: CreateProteinInput, **kwargs: Any
    ) -> CreateProteinCreateProtein:
        query = gql(
            """
            mutation create_protein($protein: CreateProteinInput!) {
              create_protein(input: $protein) {
                id
              }
            }
            """
        )
        variables: Dict[str, object] = {"protein": protein}
        response = await self.execute(query=query, variables=variables, **kwargs)
        data = self.get_data(response)
        return CreateProtein.model_validate(data).create_protein

    async def argument(self, id: UUID, **kwargs: Any) -> ArgumentArgument:
        query = gql(
            """
            query argument($id: ArgumentId!) {
              argument(id: $id) {
                ...ArgumentFull
              }
            }

            fragment ArgumentFull on Argument {
              id
              typeinfo
              value
              created_at
              rejected_at
              source
              tags
            }
            """
        )
        variables: Dict[str, object] = {"id": id}
        response = await self.execute(query=query, variables=variables, **kwargs)
        data = self.get_data(response)
        return Argument.model_validate(data).argument

    async def arguments(
        self,
        after: Union[Optional[str], UnsetType] = UNSET,
        before: Union[Optional[str], UnsetType] = UNSET,
        first: Union[Optional[int], UnsetType] = UNSET,
        last: Union[Optional[int], UnsetType] = UNSET,
        typeinfo: Union[Optional[Any], UnsetType] = UNSET,
        tags: Union[Optional[List[str]], UnsetType] = UNSET,
        **kwargs: Any
    ) -> ArgumentsMe:
        query = gql(
            """
            query arguments($after: String, $before: String, $first: Int, $last: Int, $typeinfo: Type, $tags: [String!]) {
              me {
                account {
                  arguments(
                    first: $first
                    last: $last
                    after: $after
                    before: $before
                    typeinfo: $typeinfo
                    tags: $tags
                  ) {
                    pageInfo {
                      ...PageInfoFull
                    }
                    edges {
                      cursor
                      node {
                        ...ArgumentFull
                      }
                    }
                  }
                }
              }
            }

            fragment ArgumentFull on Argument {
              id
              typeinfo
              value
              created_at
              rejected_at
              source
              tags
            }

            fragment PageInfoFull on PageInfo {
              hasPreviousPage
              hasNextPage
              startCursor
              endCursor
            }
            """
        )
        variables: Dict[str, object] = {
            "after": after,
            "before": before,
            "first": first,
            "last": last,
            "typeinfo": typeinfo,
            "tags": tags,
        }
        response = await self.execute(query=query, variables=variables, **kwargs)
        data = self.get_data(response)
        return Arguments.model_validate(data).me

    async def latest_modules(
        self,
        after: Union[Optional[str], UnsetType] = UNSET,
        before: Union[Optional[str], UnsetType] = UNSET,
        first: Union[Optional[int], UnsetType] = UNSET,
        last: Union[Optional[int], UnsetType] = UNSET,
        order: Union[Optional[OrderBy], UnsetType] = UNSET,
        names: Union[Optional[List[str]], UnsetType] = UNSET,
        **kwargs: Any
    ) -> LatestModulesLatestModules:
        query = gql(
            """
            query latest_modules($after: String, $before: String, $first: Int, $last: Int, $order: OrderBy, $names: [String!]) {
              latest_modules(
                after: $after
                before: $before
                first: $first
                last: $last
                order: $order
                names: $names
              ) {
                pageInfo {
                  ...PageInfoFull
                }
                edges {
                  cursor
                  node {
                    ...ModuleFull
                  }
                }
              }
            }

            fragment ModuleFull on Module {
              id
              created_at
              deleted_at
              path
              usage
              ins
              ins_usage
              outs
              outs_usage
              description
              typedesc
              tags
              targets
              resource_bounds {
                gpu_min
                gpu_max
                gpu_hint
                gpu_mem_min
                gpu_mem_max
                gpu_mem_hint
                cpu_min
                cpu_max
                cpu_hint
                node_min
                node_max
                node_hint
                mem_min
                mem_max
                storage_min
                storage_max
              }
            }

            fragment PageInfoFull on PageInfo {
              hasPreviousPage
              hasNextPage
              startCursor
              endCursor
            }
            """
        )
        variables: Dict[str, object] = {
            "after": after,
            "before": before,
            "first": first,
            "last": last,
            "order": order,
            "names": names,
        }
        response = await self.execute(query=query, variables=variables, **kwargs)
        data = self.get_data(response)
        return LatestModules.model_validate(data).latest_modules

    async def modules(
        self,
        after: Union[Optional[str], UnsetType] = UNSET,
        before: Union[Optional[str], UnsetType] = UNSET,
        first: Union[Optional[int], UnsetType] = UNSET,
        last: Union[Optional[int], UnsetType] = UNSET,
        path: Union[Optional[str], UnsetType] = UNSET,
        tags: Union[Optional[List[str]], UnsetType] = UNSET,
        **kwargs: Any
    ) -> ModulesModules:
        query = gql(
            """
            query modules($after: String, $before: String, $first: Int, $last: Int, $path: String, $tags: [String!]) {
              modules(
                first: $first
                last: $last
                after: $after
                before: $before
                path: $path
                tags: $tags
              ) {
                pageInfo {
                  ...PageInfoFull
                }
                edges {
                  cursor
                  node {
                    ...ModuleFull
                  }
                }
              }
            }

            fragment ModuleFull on Module {
              id
              created_at
              deleted_at
              path
              usage
              ins
              ins_usage
              outs
              outs_usage
              description
              typedesc
              tags
              targets
              resource_bounds {
                gpu_min
                gpu_max
                gpu_hint
                gpu_mem_min
                gpu_mem_max
                gpu_mem_hint
                cpu_min
                cpu_max
                cpu_hint
                node_min
                node_max
                node_hint
                mem_min
                mem_max
                storage_min
                storage_max
              }
            }

            fragment PageInfoFull on PageInfo {
              hasPreviousPage
              hasNextPage
              startCursor
              endCursor
            }
            """
        )
        variables: Dict[str, object] = {
            "after": after,
            "before": before,
            "first": first,
            "last": last,
            "path": path,
            "tags": tags,
        }
        response = await self.execute(query=query, variables=variables, **kwargs)
        data = self.get_data(response)
        return Modules.model_validate(data).modules

    async def module_instance_details(
        self,
        id: UUID,
        stderr_after: Union[Optional[str], UnsetType] = UNSET,
        stderr_before: Union[Optional[str], UnsetType] = UNSET,
        stdout_after: Union[Optional[str], UnsetType] = UNSET,
        stdout_before: Union[Optional[str], UnsetType] = UNSET,
        **kwargs: Any
    ) -> ModuleInstanceDetailsModuleInstance:
        query = gql(
            """
            query module_instance_details($id: ModuleInstanceId!, $stderr_after: String, $stderr_before: String, $stdout_after: String, $stdout_before: String) {
              module_instance(id: $id) {
                ...ModuleInstanceFull
                stdout(after: $stdout_after, before: $stdout_before) {
                  pageInfo {
                    ...PageInfoFull
                  }
                  edges {
                    cursor
                    node {
                      id
                      created_at
                      content
                    }
                  }
                }
                stderr(after: $stderr_after, before: $stderr_before) {
                  pageInfo {
                    ...PageInfoFull
                  }
                  edges {
                    cursor
                    node {
                      id
                      created_at
                      content
                    }
                  }
                }
              }
            }

            fragment ModuleInstanceCommon on ModuleInstance {
              id
              account_id
              created_at
              deleted_at
              queued_at
              admitted_at
              dispatched_at
              completed_at
              path
              status
              target
              tags
              failure_reason
              failure_context {
                stdout
                stderr
                syserr
              }
            }

            fragment ModuleInstanceFull on ModuleInstance {
              ...ModuleInstanceCommon
              ins {
                id
                created_at
                deleted_at
                rejected_at
                account_id
                typeinfo
                value
                tags
              }
              outs {
                id
                created_at
                deleted_at
                rejected_at
                account_id
                typeinfo
                value
                tags
              }
              resources {
                gpus
                nodes
                mem
                storage
                walltime
              }
              progress {
                n
                n_expected
                n_max
                done
              }
            }

            fragment PageInfoFull on PageInfo {
              hasPreviousPage
              hasNextPage
              startCursor
              endCursor
            }
            """
        )
        variables: Dict[str, object] = {
            "id": id,
            "stderr_after": stderr_after,
            "stderr_before": stderr_before,
            "stdout_after": stdout_after,
            "stdout_before": stdout_before,
        }
        response = await self.execute(query=query, variables=variables, **kwargs)
        data = self.get_data(response)
        return ModuleInstanceDetails.model_validate(data).module_instance

    async def module_instances(
        self,
        after: Union[Optional[str], UnsetType] = UNSET,
        before: Union[Optional[str], UnsetType] = UNSET,
        first: Union[Optional[int], UnsetType] = UNSET,
        last: Union[Optional[int], UnsetType] = UNSET,
        path: Union[Optional[str], UnsetType] = UNSET,
        name: Union[Optional[str], UnsetType] = UNSET,
        status: Union[Optional[ModuleInstanceStatus], UnsetType] = UNSET,
        tags: Union[Optional[List[str]], UnsetType] = UNSET,
        ids: Union[Optional[List[UUID]], UnsetType] = UNSET,
        **kwargs: Any
    ) -> ModuleInstancesMe:
        query = gql(
            """
            query module_instances($after: String, $before: String, $first: Int, $last: Int, $path: String, $name: String, $status: ModuleInstanceStatus, $tags: [String!], $ids: [ModuleInstanceId!]) {
              me {
                account {
                  module_instances(
                    first: $first
                    last: $last
                    after: $after
                    before: $before
                    path: $path
                    status: $status
                    name: $name
                    tags: $tags
                    ids: $ids
                  ) {
                    edges {
                      cursor
                      node {
                        ...SimpleModuleInstanceFull
                      }
                    }
                    pageInfo {
                      ...PageInfoFull
                    }
                  }
                }
              }
            }

            fragment PageInfoFull on PageInfo {
              hasPreviousPage
              hasNextPage
              startCursor
              endCursor
            }

            fragment SimpleModuleInstanceCommon on SimpleModuleInstance {
              id
              account_id
              created_at
              deleted_at
              queued_at
              admitted_at
              dispatched_at
              completed_at
              path
              status
              target
              tags
              failure_reason
              failure_context {
                stdout
                stderr
                syserr
              }
            }

            fragment SimpleModuleInstanceFull on SimpleModuleInstance {
              ...SimpleModuleInstanceCommon
              ins {
                id
                created_at
                deleted_at
                rejected_at
                account_id
                typeinfo
                value
                tags
              }
              outs {
                id
                created_at
                deleted_at
                rejected_at
                account_id
                typeinfo
                value
                tags
              }
              resources {
                gpus
                nodes
                mem
                storage
                walltime
              }
              progress {
                n
                n_expected
                n_max
                done
              }
            }
            """
        )
        variables: Dict[str, object] = {
            "after": after,
            "before": before,
            "first": first,
            "last": last,
            "path": path,
            "name": name,
            "status": status,
            "tags": tags,
            "ids": ids,
        }
        response = await self.execute(query=query, variables=variables, **kwargs)
        data = self.get_data(response)
        return ModuleInstances.model_validate(data).me

    async def module_instance_minimal(
        self, id: UUID, **kwargs: Any
    ) -> ModuleInstanceMinimalModuleInstance:
        query = gql(
            """
            query module_instance_minimal($id: ModuleInstanceId!) {
              module_instance(id: $id) {
                ...ModuleInstanceCommon
              }
            }

            fragment ModuleInstanceCommon on ModuleInstance {
              id
              account_id
              created_at
              deleted_at
              queued_at
              admitted_at
              dispatched_at
              completed_at
              path
              status
              target
              tags
              failure_reason
              failure_context {
                stdout
                stderr
                syserr
              }
            }
            """
        )
        variables: Dict[str, object] = {"id": id}
        response = await self.execute(query=query, variables=variables, **kwargs)
        data = self.get_data(response)
        return ModuleInstanceMinimal.model_validate(data).module_instance

    async def object(self, id: UUID, **kwargs: Any) -> Any:
        query = gql(
            """
            query object($id: ArgumentId!) {
              object(id: $id)
            }
            """
        )
        variables: Dict[str, object] = {"id": id}
        response = await self.execute(query=query, variables=variables, **kwargs)
        data = self.get_data(response)
        return Object.model_validate(data).object

    async def entity(self, id: Any, **kwargs: Any) -> Optional[EntityEntity]:
        query = gql(
            """
            query entity($id: UUID!) {
              entity(id: $id) {
                id
                createdAt
                updatedAt
                deletedAt
                data
                tags
              }
            }
            """
        )
        variables: Dict[str, object] = {"id": id}
        response = await self.execute(query=query, variables=variables, **kwargs)
        data = self.get_data(response)
        return Entity.model_validate(data).entity

    async def project(self, id: Any, **kwargs: Any) -> Optional[ProjectProject]:
        query = gql(
            """
            query project($id: UUID!) {
              project(id: $id) {
                createdAt
                updatedAt
                deletedAt
                data {
                  name
                }
                tags
                proteins {
                  edges {
                    node {
                      id
                    }
                  }
                }
                protein_conformers {
                  edges {
                    node {
                      id
                    }
                  }
                }
                smols {
                  edges {
                    node {
                      id
                    }
                  }
                }
                smol_conformers {
                  edges {
                    node {
                      id
                    }
                  }
                }
                smol_tautomers {
                  edges {
                    node {
                      id
                    }
                  }
                }
              }
            }
            """
        )
        variables: Dict[str, object] = {"id": id}
        response = await self.execute(query=query, variables=variables, **kwargs)
        data = self.get_data(response)
        return Project.model_validate(data).project

    async def protein(self, id: Any, **kwargs: Any) -> Optional[ProteinProtein]:
        query = gql(
            """
            query protein($id: UUID!) {
              protein(id: $id) {
                id
                createdAt
                updatedAt
                deletedAt
                data {
                  name
                  sequence
                }
                tags
              }
            }
            """
        )
        variables: Dict[str, object] = {"id": id}
        response = await self.execute(query=query, variables=variables, **kwargs)
        data = self.get_data(response)
        return Protein.model_validate(data).protein

    async def protein_conformer(
        self, id: Any, **kwargs: Any
    ) -> Optional[ProteinConformerProteinConformer]:
        query = gql(
            """
            query protein_conformer($id: UUID!) {
              protein_conformer(id: $id) {
                id
                createdAt
                updatedAt
                deletedAt
                data {
                  name
                }
                tags
              }
            }
            """
        )
        variables: Dict[str, object] = {"id": id}
        response = await self.execute(query=query, variables=variables, **kwargs)
        data = self.get_data(response)
        return ProteinConformer.model_validate(data).protein_conformer

    async def smol(self, id: Any, **kwargs: Any) -> Optional[SmolSmol]:
        query = gql(
            """
            query smol($id: UUID!) {
              smol(id: $id) {
                id
                createdAt
                updatedAt
                deletedAt
                data {
                  name
                  inchi
                }
                tags
              }
            }
            """
        )
        variables: Dict[str, object] = {"id": id}
        response = await self.execute(query=query, variables=variables, **kwargs)
        data = self.get_data(response)
        return Smol.model_validate(data).smol

    async def smol_conformer(
        self, id: Any, **kwargs: Any
    ) -> Optional[SmolConformerSmolConformer]:
        query = gql(
            """
            query smol_conformer($id: UUID!) {
              smol_conformer(id: $id) {
                id
                createdAt
                updatedAt
                deletedAt
                data {
                  name
                }
                tags
              }
            }
            """
        )
        variables: Dict[str, object] = {"id": id}
        response = await self.execute(query=query, variables=variables, **kwargs)
        data = self.get_data(response)
        return SmolConformer.model_validate(data).smol_conformer

    async def smol_tautomer(
        self, id: Any, **kwargs: Any
    ) -> Optional[SmolTautomerSmolTautomer]:
        query = gql(
            """
            query smol_tautomer($id: UUID!) {
              smol_tautomer(id: $id) {
                id
                createdAt
                updatedAt
                deletedAt
                data {
                  name
                  inchi
                }
                tags
              }
            }
            """
        )
        variables: Dict[str, object] = {"id": id}
        response = await self.execute(query=query, variables=variables, **kwargs)
        data = self.get_data(response)
        return SmolTautomer.model_validate(data).smol_tautomer

    async def structure(self, id: Any, **kwargs: Any) -> Optional[StructureStructure]:
        query = gql(
            """
            query structure($id: UUID!) {
              structure(id: $id) {
                id
                createdAt
                updatedAt
                deletedAt
                data {
                  name
                }
                topology {
                  symbols
                  geometry
                  connectivity
                  atom_charges
                  atom_labels
                  partial_charges
                  fragments
                  fragment_charges
                  alts
                }
                tags
              }
            }
            """
        )
        variables: Dict[str, object] = {"id": id}
        response = await self.execute(query=query, variables=variables, **kwargs)
        data = self.get_data(response)
        return Structure.model_validate(data).structure

    async def experiment(
        self, id: Any, **kwargs: Any
    ) -> Optional[ExperimentExperiment]:
        query = gql(
            """
            query experiment($id: UUID!) {
              experiment(id: $id) {
                id
                createdAt
                updatedAt
                deletedAt
                data {
                  name
                  unit
                  measure
                  value
                  assay
                }
                tags
              }
            }
            """
        )
        variables: Dict[str, object] = {"id": id}
        response = await self.execute(query=query, variables=variables, **kwargs)
        data = self.get_data(response)
        return Experiment.model_validate(data).experiment

    async def retry(
        self,
        instance: UUID,
        target: ModuleInstanceTarget,
        resources: Union[Optional[ModuleInstanceResourcesInput], UnsetType] = UNSET,
        **kwargs: Any
    ) -> RetryRetry:
        query = gql(
            """
            mutation retry($instance: ModuleInstanceId!, $target: ModuleInstanceTarget!, $resources: ModuleInstanceResourcesInput) {
              retry(instance: $instance, target: $target, resources: $resources) {
                id
              }
            }
            """
        )
        variables: Dict[str, object] = {
            "instance": instance,
            "target": target,
            "resources": resources,
        }
        response = await self.execute(query=query, variables=variables, **kwargs)
        data = self.get_data(response)
        return Retry.model_validate(data).retry

    async def run(self, instance: ModuleInstanceInput, **kwargs: Any) -> RunRun:
        query = gql(
            """
            mutation run($instance: ModuleInstanceInput!) {
              run(instance: $instance) {
                id
                outs {
                  id
                }
              }
            }
            """
        )
        variables: Dict[str, object] = {"instance": instance}
        response = await self.execute(query=query, variables=variables, **kwargs)
        data = self.get_data(response)
        return Run.model_validate(data).run

    async def create_smol_conformer(
        self, smol_conformer: CreateSmolConformerInput, **kwargs: Any
    ) -> CreateSmolConformerCreateSmolConformer:
        query = gql(
            """
            mutation create_smol_conformer($smol_conformer: CreateSmolConformerInput!) {
              create_smol_conformer(input: $smol_conformer) {
                id
              }
            }
            """
        )
        variables: Dict[str, object] = {"smol_conformer": smol_conformer}
        response = await self.execute(query=query, variables=variables, **kwargs)
        data = self.get_data(response)
        return CreateSmolConformer.model_validate(data).create_smol_conformer

    async def create_smol(
        self, smol: CreateSmolInput, **kwargs: Any
    ) -> CreateSmolCreateSmol:
        query = gql(
            """
            mutation create_smol($smol: CreateSmolInput!) {
              create_smol(input: $smol) {
                id
              }
            }
            """
        )
        variables: Dict[str, object] = {"smol": smol}
        response = await self.execute(query=query, variables=variables, **kwargs)
        data = self.get_data(response)
        return CreateSmol.model_validate(data).create_smol

    async def create_smol_tautomer(
        self, smol_tautomer: CreateSmolTautomerInput, **kwargs: Any
    ) -> CreateSmolTautomerCreateSmolTautomer:
        query = gql(
            """
            mutation create_smol_tautomer($smol_tautomer: CreateSmolTautomerInput!) {
              create_smol_tautomer(input: $smol_tautomer) {
                id
              }
            }
            """
        )
        variables: Dict[str, object] = {"smol_tautomer": smol_tautomer}
        response = await self.execute(query=query, variables=variables, **kwargs)
        data = self.get_data(response)
        return CreateSmolTautomer.model_validate(data).create_smol_tautomer

    async def create_structure(
        self, structure: CreateStructureInput, **kwargs: Any
    ) -> CreateStructureCreateStructure:
        query = gql(
            """
            mutation create_structure($structure: CreateStructureInput!) {
              create_structure(input: $structure) {
                id
              }
            }
            """
        )
        variables: Dict[str, object] = {"structure": structure}
        response = await self.execute(query=query, variables=variables, **kwargs)
        data = self.get_data(response)
        return CreateStructure.model_validate(data).create_structure

    async def tag(
        self,
        tags: List[str],
        module_instance_id: Union[Optional[UUID], UnsetType] = UNSET,
        argument_id: Union[Optional[UUID], UnsetType] = UNSET,
        module_id: Union[Optional[UUID], UnsetType] = UNSET,
        **kwargs: Any
    ) -> List[str]:
        query = gql(
            """
            mutation tag($moduleInstanceId: ModuleInstanceId, $argumentId: ArgumentId, $moduleId: ModuleId, $tags: [String!]!) {
              tag(
                module_instance: $moduleInstanceId
                argument: $argumentId
                module: $moduleId
                tags: $tags
              )
            }
            """
        )
        variables: Dict[str, object] = {
            "moduleInstanceId": module_instance_id,
            "argumentId": argument_id,
            "moduleId": module_id,
            "tags": tags,
        }
        response = await self.execute(query=query, variables=variables, **kwargs)
        data = self.get_data(response)
        return Tag.model_validate(data).tag

    async def track_utilization(
        self, utilization: ResourceUtilizationInput, **kwargs: Any
    ) -> TrackUtilizationTrackModuleInstanceResourceUtilization:
        query = gql(
            """
            mutation track_utilization($utilization: ResourceUtilizationInput!) {
              track_module_instance_resource_utilization(utilization: $utilization) {
                id
              }
            }
            """
        )
        variables: Dict[str, object] = {"utilization": utilization}
        response = await self.execute(query=query, variables=variables, **kwargs)
        data = self.get_data(response)
        return TrackUtilization.model_validate(
            data
        ).track_module_instance_resource_utilization

    async def untag(
        self,
        tags: List[str],
        module_instance_id: Union[Optional[UUID], UnsetType] = UNSET,
        argument_id: Union[Optional[UUID], UnsetType] = UNSET,
        module_id: Union[Optional[UUID], UnsetType] = UNSET,
        **kwargs: Any
    ) -> List[str]:
        query = gql(
            """
            mutation untag($moduleInstanceId: ModuleInstanceId, $argumentId: ArgumentId, $moduleId: ModuleId, $tags: [String!]!) {
              untag(
                module_instance: $moduleInstanceId
                argument: $argumentId
                module: $moduleId
                tags: $tags
              )
            }
            """
        )
        variables: Dict[str, object] = {
            "moduleInstanceId": module_instance_id,
            "argumentId": argument_id,
            "moduleId": module_id,
            "tags": tags,
        }
        response = await self.execute(query=query, variables=variables, **kwargs)
        data = self.get_data(response)
        return Untag.model_validate(data).untag

    async def update_module_instance(
        self, module_instance_update: UpdateModuleInstanceInput, **kwargs: Any
    ) -> UpdateModuleInstanceUpdateModuleInstance:
        query = gql(
            """
            mutation update_module_instance($moduleInstanceUpdate: UpdateModuleInstanceInput!) {
              update_module_instance(instance_update: $moduleInstanceUpdate) {
                id
                status
              }
            }
            """
        )
        variables: Dict[str, object] = {"moduleInstanceUpdate": module_instance_update}
        response = await self.execute(query=query, variables=variables, **kwargs)
        data = self.get_data(response)
        return UpdateModuleInstance.model_validate(data).update_module_instance

    async def upload_arg(
        self, typeinfo: Any, file: Upload, **kwargs: Any
    ) -> UploadArgUploadArg:
        query = gql(
            """
            mutation upload_arg($typeinfo: JSON!, $file: Upload!) {
              upload_arg(typeinfo: $typeinfo, file: $file) {
                id
                value
              }
            }
            """
        )
        variables: Dict[str, object] = {"typeinfo": typeinfo, "file": file}
        response = await self.execute(query=query, variables=variables, **kwargs)
        data = self.get_data(response)
        return UploadArg.model_validate(data).upload_arg



# Generated by ariadne-codegen
# Source: combined.graphql

from typing import Any

from .base_model import BaseModel


class CreateExperiment(BaseModel):
    create_experiment: "CreateExperimentCreateExperiment"


class CreateExperimentCreateExperiment(BaseModel):
    id: Any


CreateExperiment.model_rebuild()
CreateExperimentCreateExperiment.model_rebuild()



# Generated by ariadne-codegen
# Source: combined.graphql

from typing import Any

from .base_model import BaseModel


class CreateSmol(BaseModel):
    create_smol: "CreateSmolCreateSmol"


class CreateSmolCreateSmol(BaseModel):
    id: Any


CreateSmol.model_rebuild()
CreateSmolCreateSmol.model_rebuild()



# Generated by ariadne-codegen
# Source: combined.graphql

from typing import Any, Optional
from uuid import UUID

from .base_model import BaseModel


class UploadArg(BaseModel):
    upload_arg: "UploadArgUploadArg"


class UploadArgUploadArg(BaseModel):
    id: UUID
    value: Optional[Any]


UploadArg.model_rebuild()
UploadArgUploadArg.model_rebuild()



# Generated by ariadne-codegen
# Source: combined.graphql

from typing import Any

from .base_model import BaseModel


class CreateStructure(BaseModel):
    create_structure: "CreateStructureCreateStructure"


class CreateStructureCreateStructure(BaseModel):
    id: Any


CreateStructure.model_rebuild()
CreateStructureCreateStructure.model_rebuild()



# Generated by ariadne-codegen
# Source: combined.graphql

from typing import Any

from .base_model import BaseModel


class CreateProteinConformer(BaseModel):
    create_protein_conformer: "CreateProteinConformerCreateProteinConformer"


class CreateProteinConformerCreateProteinConformer(BaseModel):
    id: Any


CreateProteinConformer.model_rebuild()
CreateProteinConformerCreateProteinConformer.model_rebuild()



# Generated by ariadne-codegen
# Source: schema.graphql

from enum import Enum


class Element(str, Enum):
    H = "H"
    HE = "HE"
    LI = "LI"
    BE = "BE"
    B = "B"
    C = "C"
    N = "N"
    O = "O"
    F = "F"
    NE = "NE"
    NA = "NA"
    MG = "MG"
    AL = "AL"
    SI = "SI"
    P = "P"
    S = "S"
    CL = "CL"
    AR = "AR"
    K = "K"
    CA = "CA"
    SC = "SC"
    TI = "TI"
    V = "V"
    CR = "CR"
    MN = "MN"
    FE = "FE"
    CO = "CO"
    NI = "NI"
    CU = "CU"
    ZN = "ZN"
    GA = "GA"
    GE = "GE"
    AS = "AS"
    SE = "SE"
    BR = "BR"
    KR = "KR"
    RB = "RB"
    SR = "SR"
    Y = "Y"
    ZR = "ZR"
    NB = "NB"
    MO = "MO"
    TC = "TC"
    RU = "RU"
    RH = "RH"
    PD = "PD"
    AG = "AG"
    CD = "CD"
    IN = "IN"
    SN = "SN"
    SB = "SB"
    TE = "TE"
    I = "I"
    XE = "XE"
    CS = "CS"
    BA = "BA"
    LA = "LA"
    CE = "CE"
    PR = "PR"
    ND = "ND"
    PM = "PM"
    SM = "SM"
    EU = "EU"
    GD = "GD"
    TB = "TB"
    DY = "DY"
    HO = "HO"
    ER = "ER"
    TM = "TM"
    YB = "YB"
    LU = "LU"
    HF = "HF"
    TA = "TA"
    W = "W"
    RE = "RE"
    OS = "OS"
    IR = "IR"
    PT = "PT"
    AU = "AU"
    HG = "HG"
    TL = "TL"
    PB = "PB"
    BI = "BI"
    PO = "PO"
    AT = "AT"
    RN = "RN"
    FR = "FR"
    RA = "RA"
    AC = "AC"
    TH = "TH"
    PA = "PA"
    U = "U"
    NP = "NP"
    PU = "PU"
    AM = "AM"
    CM = "CM"
    BK = "BK"
    CF = "CF"
    ES = "ES"
    FM = "FM"
    MD = "MD"
    NO = "NO"
    LR = "LR"
    RF = "RF"
    DB = "DB"
    SG = "SG"
    BH = "BH"
    HS = "HS"
    MT = "MT"
    DS = "DS"
    RG = "RG"
    CN = "CN"
    NH = "NH"
    FL = "FL"
    MC = "MC"
    LV = "LV"
    TS = "TS"
    OG = "OG"


class MemUnits(str, Enum):
    B = "B"
    KB = "KB"
    MB = "MB"
    GB = "GB"
    TB = "TB"


class ModuleFailureReason(str, Enum):
    RESOLUTION = "RESOLUTION"
    DISPATCH = "DISPATCH"
    RUN = "RUN"
    STALLED = "STALLED"
    MISSING = "MISSING"
    CORRUPTED = "CORRUPTED"


class ModuleInstanceStatus(str, Enum):
    CREATED = "CREATED"
    RESOLVING = "RESOLVING"
    ADMITTED = "ADMITTED"
    DISPATCHED = "DISPATCHED"
    QUEUED = "QUEUED"
    RUNNING = "RUNNING"
    AWAITING_UPLOAD = "AWAITING_UPLOAD"
    COMPLETED = "COMPLETED"
    FAILED = "FAILED"
    CANCELLED = "CANCELLED"


class ModuleInstanceTarget(str, Enum):
    NIX = "NIX"
    GADI = "GADI"
    NIX_SSH = "NIX_SSH"
    NIX_SSH_2 = "NIX_SSH_2"
    NIX_SSH_3 = "NIX_SSH_3"
    NIX_SSH_4 = "NIX_SSH_4"
    SETONIX = "SETONIX"
    GADI_GPU = "GADI_GPU"
    NIX_SSH_GPU = "NIX_SSH_GPU"
    NIX_SSH_2_GPU = "NIX_SSH_2_GPU"
    NIX_SSH_3_GPU = "NIX_SSH_3_GPU"
    NIX_SSH_4_GPU = "NIX_SSH_4_GPU"
    SETONIX_GPU = "SETONIX_GPU"
    GADI_EXPRESS = "GADI_EXPRESS"
    SETONIX_EXPRESS = "SETONIX_EXPRESS"


class Order(str, Enum):
    ASC = "ASC"
    DESC = "DESC"


class OrderBy(str, Enum):
    ASC = "ASC"
    DESC = "DESC"



# Generated by ariadne-codegen
# Source: schema.graphql

from datetime import datetime
from typing import Any, List, Optional
from uuid import UUID

from pydantic import Field

from .base_model import BaseModel
from .enums import Element, MemUnits, ModuleInstanceStatus, ModuleInstanceTarget, Order


class ArgumentInput(BaseModel):
    id: Optional[UUID] = None
    value: Optional[Any] = None
    tags: Optional[List[str]] = None


class CreateExperimentInput(BaseModel):
    name: str
    data: "ExperimentDataInput"
    project_id: Any
    smol_id: Any
    protein_id: Any
    tags: List[str]


class CreateProjectInput(BaseModel):
    name: str
    tags: List[str]


class CreateProteinConformerInput(BaseModel):
    name: Optional[str] = None
    project_id: Any
    protein_id: Any
    structure_id: Any
    tags: List[str]


class CreateProteinInput(BaseModel):
    name: str
    sequence: str
    project_id: Any
    protein_id: Optional[Any] = None
    tags: List[str]


class CreateSmolConformerInput(BaseModel):
    name: Optional[str] = None
    smol_id: Any
    smol_tautomer_id: Any
    structure_id: Any
    project_id: Any
    tags: List[str]


class CreateSmolInput(BaseModel):
    name: str
    data: "SmolDataInput"
    project_id: Any
    tags: List[str]


class CreateSmolTautomerInput(BaseModel):
    name: Optional[str] = None
    data: "SmolTautomerDataInput"
    smol_id: Any
    project_id: Any
    tags: List[str]


class CreateStructureInput(BaseModel):
    name: str
    topology: "TopologyInput"
    project_id: Any
    trajectory_id: Optional[Any] = None
    tags: List[str]


class DateTimeFilter(BaseModel):
    eq: Optional[datetime] = None
    ne: Optional[datetime] = None
    gt: Optional[datetime] = None
    ge: Optional[datetime] = None
    lt: Optional[datetime] = None
    le: Optional[datetime] = None


class EntityFilterBy(BaseModel):
    and_: Optional[List["EntityFilterBy"]] = Field(alias="and", default=None)
    or_: Optional[List["EntityFilterBy"]] = Field(alias="or", default=None)
    not_: Optional["EntityFilterBy"] = Field(alias="not", default=None)
    id: Optional["UuidFilter"] = None
    created_at: Optional["DateTimeFilter"] = None
    updated_at: Optional["DateTimeFilter"] = None
    deleted_at: Optional["DateTimeFilter"] = None
    tags: Optional["TagFilter"] = None


class EntitySortBy(BaseModel):
    id: Optional[Order] = None
    created_at: Optional[Order] = None
    updated_at: Optional[Order] = None
    deleted_at: Optional[Order] = None


class ExperimentDataInput(BaseModel):
    unit: str
    measure: str
    value: float
    assay: str


class ExperimentFilterBy(BaseModel):
    and_: Optional[List["ExperimentFilterBy"]] = Field(alias="and", default=None)
    or_: Optional[List["ExperimentFilterBy"]] = Field(alias="or", default=None)
    not_: Optional["ExperimentFilterBy"] = Field(alias="not", default=None)
    id: Optional["UuidFilter"] = None
    created_at: Optional["DateTimeFilter"] = None
    updated_at: Optional["DateTimeFilter"] = None
    deleted_at: Optional["DateTimeFilter"] = None
    tags: Optional["TagFilter"] = None
    project_id: Optional["UuidFilter"] = None


class ExperimentSortBy(BaseModel):
    id: Optional[Order] = None
    created_at: Optional[Order] = None
    updated_at: Optional[Order] = None
    deleted_at: Optional[Order] = None


class ModuleInput(BaseModel):
    path: str
    tags: Optional[List[str]] = None
    tests: List["TestCase"]


class ModuleInstanceInput(BaseModel):
    path: str
    args: List["ArgumentInput"]
    target: Optional[ModuleInstanceTarget] = None
    resources: Optional["ModuleInstanceResourcesInput"] = None
    tags: Optional[List[str]] = None
    out_tags: Optional[List[Optional[List[str]]]] = None
    end: Optional[bool] = None


class ModuleInstanceResourcesInput(BaseModel):
    gpus: Optional[int] = None
    gpu_mem: Optional[int] = None
    gpu_mem_units: Optional[MemUnits] = None
    cpus: Optional[int] = None
    nodes: Optional[int] = None
    mem: Optional[int] = None
    mem_units: Optional[MemUnits] = None
    storage: Optional[int] = None
    storage_units: Optional[MemUnits] = None
    walltime: Optional[int] = None
    storage_mounts: Optional[List[str]] = None


class ProjectFilterBy(BaseModel):
    and_: Optional[List["ProjectFilterBy"]] = Field(alias="and", default=None)
    or_: Optional[List["ProjectFilterBy"]] = Field(alias="or", default=None)
    not_: Optional["ProjectFilterBy"] = Field(alias="not", default=None)
    id: Optional["UuidFilter"] = None
    created_at: Optional["DateTimeFilter"] = None
    updated_at: Optional["DateTimeFilter"] = None
    deleted_at: Optional["DateTimeFilter"] = None
    tags: Optional["TagFilter"] = None


class ProjectSortBy(BaseModel):
    id: Optional[Order] = None
    created_at: Optional[Order] = None
    updated_at: Optional[Order] = None
    deleted_at: Optional[Order] = None


class ProteinConformerFilterBy(BaseModel):
    and_: Optional[List["ProteinConformerFilterBy"]] = Field(alias="and", default=None)
    or_: Optional[List["ProteinConformerFilterBy"]] = Field(alias="or", default=None)
    not_: Optional["ProteinConformerFilterBy"] = Field(alias="not", default=None)
    id: Optional["UuidFilter"] = None
    created_at: Optional["DateTimeFilter"] = None
    updated_at: Optional["DateTimeFilter"] = None
    deleted_at: Optional["DateTimeFilter"] = None
    tags: Optional["TagFilter"] = None
    project_id: Optional["UuidFilter"] = None


class ProteinConformerSortBy(BaseModel):
    id: Optional[Order] = None
    created_at: Optional[Order] = None
    updated_at: Optional[Order] = None
    deleted_at: Optional[Order] = None


class ProteinFilterBy(BaseModel):
    and_: Optional[List["ProteinFilterBy"]] = Field(alias="and", default=None)
    or_: Optional[List["ProteinFilterBy"]] = Field(alias="or", default=None)
    not_: Optional["ProteinFilterBy"] = Field(alias="not", default=None)
    id: Optional["UuidFilter"] = None
    created_at: Optional["DateTimeFilter"] = None
    updated_at: Optional["DateTimeFilter"] = None
    deleted_at: Optional["DateTimeFilter"] = None
    tags: Optional["TagFilter"] = None
    project_id: Optional["UuidFilter"] = None


class ProteinSortBy(BaseModel):
    id: Optional[Order] = None
    created_at: Optional[Order] = None
    updated_at: Optional[Order] = None
    deleted_at: Optional[Order] = None


class RawEntityInput(BaseModel):
    data: Optional[Any] = None
    tags: List[str]


class ResourceUtilizationInput(BaseModel):
    module_instance_id: UUID = Field(alias="moduleInstanceId")
    gpu: Optional[float] = None
    mem: Optional[float] = None
    storage: float
    walltime: float
    cputime: float
    inodes: float
    sus: Optional[int] = None


class SmolConformerFilterBy(BaseModel):
    and_: Optional[List["SmolConformerFilterBy"]] = Field(alias="and", default=None)
    or_: Optional[List["SmolConformerFilterBy"]] = Field(alias="or", default=None)
    not_: Optional["SmolConformerFilterBy"] = Field(alias="not", default=None)
    id: Optional["UuidFilter"] = None
    created_at: Optional["DateTimeFilter"] = None
    updated_at: Optional["DateTimeFilter"] = None
    deleted_at: Optional["DateTimeFilter"] = None
    tags: Optional["TagFilter"] = None
    project_id: Optional["UuidFilter"] = None


class SmolConformerSortBy(BaseModel):
    id: Optional[Order] = None
    created_at: Optional[Order] = None
    updated_at: Optional[Order] = None
    deleted_at: Optional[Order] = None


class SmolDataInput(BaseModel):
    smi: Optional[str] = None
    inchi: str


class SmolFilterBy(BaseModel):
    and_: Optional[List["SmolFilterBy"]] = Field(alias="and", default=None)
    or_: Optional[List["SmolFilterBy"]] = Field(alias="or", default=None)
    not_: Optional["SmolFilterBy"] = Field(alias="not", default=None)
    id: Optional["UuidFilter"] = None
    created_at: Optional["DateTimeFilter"] = None
    updated_at: Optional["DateTimeFilter"] = None
    deleted_at: Optional["DateTimeFilter"] = None
    tags: Optional["TagFilter"] = None
    project_id: Optional["UuidFilter"] = None
    smol_name: Optional["StringFilter"] = None


class SmolSortBy(BaseModel):
    id: Optional[Order] = None
    created_at: Optional[Order] = None
    updated_at: Optional[Order] = None
    deleted_at: Optional[Order] = None


class SmolTautomerDataInput(BaseModel):
    inchi: str


class SmolTautomerFilterBy(BaseModel):
    and_: Optional[List["SmolTautomerFilterBy"]] = Field(alias="and", default=None)
    or_: Optional[List["SmolTautomerFilterBy"]] = Field(alias="or", default=None)
    not_: Optional["SmolTautomerFilterBy"] = Field(alias="not", default=None)
    id: Optional["UuidFilter"] = None
    created_at: Optional["DateTimeFilter"] = None
    updated_at: Optional["DateTimeFilter"] = None
    deleted_at: Optional["DateTimeFilter"] = None
    tags: Optional["TagFilter"] = None
    project_id: Optional["UuidFilter"] = None


class SmolTautomerSortBy(BaseModel):
    id: Optional[Order] = None
    created_at: Optional[Order] = None
    updated_at: Optional[Order] = None
    deleted_at: Optional[Order] = None


class StringFilter(BaseModel):
    eq: Optional[str] = None
    ne: Optional[str] = None
    gt: Optional[str] = None
    ge: Optional[str] = None
    lt: Optional[str] = None
    le: Optional[str] = None
    like: Optional[str] = None
    in_: Optional[List[str]] = Field(alias="in", default=None)
    not_in: Optional[List[str]] = None


class StructureFilterBy(BaseModel):
    and_: Optional[List["StructureFilterBy"]] = Field(alias="and", default=None)
    or_: Optional[List["StructureFilterBy"]] = Field(alias="or", default=None)
    not_: Optional["StructureFilterBy"] = Field(alias="not", default=None)
    id: Optional["UuidFilter"] = None
    created_at: Optional["DateTimeFilter"] = None
    updated_at: Optional["DateTimeFilter"] = None
    deleted_at: Optional["DateTimeFilter"] = None
    tags: Optional["TagFilter"] = None
    project_id: Optional["UuidFilter"] = None


class StructureSortBy(BaseModel):
    id: Optional[Order] = None
    created_at: Optional[Order] = None
    updated_at: Optional[Order] = None
    deleted_at: Optional[Order] = None


class TagFilter(BaseModel):
    all: Optional[List[str]] = None
    any: Optional[List[str]] = None


class TestCase(BaseModel):
    args: List["ArgumentInput"]
    target: ModuleInstanceTarget
    resources: Optional["ModuleInstanceResourcesInput"] = None
    tags: Optional[List[str]] = None


class TokenFilterBy(BaseModel):
    and_: Optional[List["TokenFilterBy"]] = Field(alias="and", default=None)
    or_: Optional[List["TokenFilterBy"]] = Field(alias="or", default=None)
    not_: Optional["TokenFilterBy"] = Field(alias="not", default=None)
    id: Optional["UuidFilter"] = None
    created_at: Optional["DateTimeFilter"] = None
    updated_at: Optional["DateTimeFilter"] = None
    deleted_at: Optional["DateTimeFilter"] = None
    tags: Optional["TagFilter"] = None


class TokenSortBy(BaseModel):
    id: Optional[Order] = None
    created_at: Optional[Order] = None
    updated_at: Optional[Order] = None
    deleted_at: Optional[Order] = None


class TopologyInput(BaseModel):
    symbols: List[Element]
    geometry: List[float]
    connectivity: Optional[List[Any]] = None
    atom_charges: Optional[List[int]] = None
    partial_charges: Optional[List[float]] = None
    atom_labels: Optional[List[str]] = None
    fragments: Optional[List[List[int]]] = None
    fragment_charges: Optional[List[int]] = None
    fragment_multiplicities: Optional[List[int]] = None
    alts: Optional[List[Any]] = None


class UpdateModuleInstanceInput(BaseModel):
    id: UUID
    path: Optional[str] = None
    ins: Optional[List["ArgumentInput"]] = None
    outs: Optional[List["ArgumentInput"]] = None
    target: Optional[ModuleInstanceTarget] = None
    status: Optional[ModuleInstanceStatus] = None
    resources: Optional["ModuleInstanceResourcesInput"] = None
    tags: Optional[List[str]] = None


class UuidFilter(BaseModel):
    eq: Optional[Any] = None
    ne: Optional[Any] = None
    in_: Optional[List[Any]] = Field(alias="in", default=None)


ArgumentInput.model_rebuild()
CreateExperimentInput.model_rebuild()
CreateProjectInput.model_rebuild()
CreateProteinConformerInput.model_rebuild()
CreateProteinInput.model_rebuild()
CreateSmolConformerInput.model_rebuild()
CreateSmolInput.model_rebuild()
CreateSmolTautomerInput.model_rebuild()
CreateStructureInput.model_rebuild()
DateTimeFilter.model_rebuild()
EntityFilterBy.model_rebuild()
EntitySortBy.model_rebuild()
ExperimentDataInput.model_rebuild()
ExperimentFilterBy.model_rebuild()
ExperimentSortBy.model_rebuild()
ModuleInput.model_rebuild()
ModuleInstanceInput.model_rebuild()
ModuleInstanceResourcesInput.model_rebuild()
ProjectFilterBy.model_rebuild()
ProjectSortBy.model_rebuild()
ProteinConformerFilterBy.model_rebuild()
ProteinConformerSortBy.model_rebuild()
ProteinFilterBy.model_rebuild()
ProteinSortBy.model_rebuild()
RawEntityInput.model_rebuild()
ResourceUtilizationInput.model_rebuild()
SmolConformerFilterBy.model_rebuild()
SmolConformerSortBy.model_rebuild()
SmolDataInput.model_rebuild()
SmolFilterBy.model_rebuild()
SmolSortBy.model_rebuild()
SmolTautomerDataInput.model_rebuild()
SmolTautomerFilterBy.model_rebuild()
SmolTautomerSortBy.model_rebuild()
StringFilter.model_rebuild()
StructureFilterBy.model_rebuild()
StructureSortBy.model_rebuild()
TagFilter.model_rebuild()
TestCase.model_rebuild()
TokenFilterBy.model_rebuild()
TokenSortBy.model_rebuild()
TopologyInput.model_rebuild()
UpdateModuleInstanceInput.model_rebuild()
UuidFilter.model_rebuild()



#!/usr/bin/env python3
import asyncio

from . import provider

_x = provider.Provider()
fns = asyncio.run(_x.get_module_functions())
TenguProvider = type(
    "TenguProvider",
    (provider.Provider,),
    fns | {n: getattr(_x, n) for n in dir(_x)},
)



# Generated by ariadne-codegen
# Source: combined.graphql

from uuid import UUID

from .base_model import BaseModel
from .enums import ModuleInstanceStatus


class UpdateModuleInstance(BaseModel):
    update_module_instance: "UpdateModuleInstanceUpdateModuleInstance"


class UpdateModuleInstanceUpdateModuleInstance(BaseModel):
    id: UUID
    status: ModuleInstanceStatus


UpdateModuleInstance.model_rebuild()
UpdateModuleInstanceUpdateModuleInstance.model_rebuild()



# Generated by ariadne-codegen
# Source: combined.graphql

from datetime import datetime
from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import Element


class Structure(BaseModel):
    structure: Optional["StructureStructure"]


class StructureStructure(BaseModel):
    id: Any
    created_at: datetime = Field(alias="createdAt")
    updated_at: datetime = Field(alias="updatedAt")
    deleted_at: Optional[datetime] = Field(alias="deletedAt")
    data: Optional["StructureStructureData"]
    topology: "StructureStructureTopology"
    tags: List[str]


class StructureStructureData(BaseModel):
    name: str


class StructureStructureTopology(BaseModel):
    symbols: List[Element]
    geometry: List[float]
    connectivity: Optional[List[Any]]
    atom_charges: Optional[List[int]]
    atom_labels: Optional[List[str]]
    partial_charges: Optional[List[float]]
    fragments: Optional[List[List[int]]]
    fragment_charges: Optional[List[int]]
    alts: Optional[List[Any]]


Structure.model_rebuild()
StructureStructure.model_rebuild()
StructureStructureData.model_rebuild()
StructureStructureTopology.model_rebuild()



# Generated by ariadne-codegen
# Source: combined.graphql

from uuid import UUID

from .base_model import BaseModel


class CancelModuleInstance(BaseModel):
    cancel: UUID


CancelModuleInstance.model_rebuild()



# Generated by ariadne-codegen
# Source: combined.graphql

from typing import Any

from .base_model import BaseModel


class CreateEntity(BaseModel):
    create_entity: "CreateEntityCreateEntity"


class CreateEntityCreateEntity(BaseModel):
    id: Any


CreateEntity.model_rebuild()
CreateEntityCreateEntity.model_rebuild()
